@@ -22,7 +22,8 @@ namespace Model
     ONEZONE_IA,
     INTELLIGENT_TIERING,
     GLACIER,
-    DEEP_ARCHIVE
+    DEEP_ARCHIVE,
+    OUTPOSTS
   };
 
 namespace StorageClassMapper
